# :cloud: :snowflake: weather_forecast :open_umbrella: :satellite:



The pip package provides weather forecasting information based on location or address. Using address, the weather_forecast provides location specific forecast. Currently only one function is included i.e forecast. 



### Install :computer:
```
pip install w_forecast
```

### Code Usage :video_game:
```
import w_forecast as wf
d = wf.forecast(place = "Bangalore" , time="23:15:00" , date="2019-09-12" , forecast)
```





```
